==> xlniuxdata-vipgame-1.0.65-20170531.123143-83-sources.jar: com/xunlei/niux/data/vipgame/vo/RebateApply.java <==


package com.xunlei.niux.data.vipgame.vo;




import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 返利申请
 * @author 李苏
 * @date 2013-11-07
 * @Descripter:
 */
@Table(tableName="rebateapply",pkFieldName="seqid",pkFieldAssign=false)
public class RebateApply {

	private Long seqid;
	private String aporderid;
	private Integer applyType;
	private String rebateType;
	private String username;
	private String inputBy;
	private String applyTime;
	private String toaccount;
	private String uid;
	private Integer vipGrade;
	private String gameid;
	private String serverid;
	private String roleid;
	private Double money;
	private Double rebatemoney;
	private String reason;
	private String crid;
	private Integer checkstatus;
	private String lastChecker;
	private String lastCheckTime;
	@Column(columnName="lastCheckTime",isWhereColumn=true,operator=Operator.GE)
	private String fromLastCheckTime;
	@Column(columnName="lastCheckTime",isWhereColumn=true,operator=Operator.LT)
	private String toLastCheckTime;
	@Column(columnName="applyTime",isWhereColumn=true,operator=Operator.GE)
	private String fromApplyTime;
	@Column(columnName="applyTime",isWhereColumn=true,operator=Operator.LT)
	private String toApplyTime;
	
	private String orderid;
	private Double consumemoney;
	private Double paymoney;
    private String propName;
	private String receiver;
	private Double equalMoney;
	private Boolean isSuccess;
	private String editBy;
	private String editTime;
	private Long realConsumeMoney;
	private Boolean isServer;
	private Integer workType;
	private String callTime;
	private String rtypeNo;
    private Integer monthCount;
    private Integer totalCount;
	private Boolean isReaded;

	public Boolean getIsReaded() {
		return isReaded;
	}

	public void setIsReaded(Boolean readed) {
		isReaded = readed;
	}

	public Integer getTotalCount() {
        return totalCount;
    }

    public void setTotalCount(Integer totalCount) {
        this.totalCount = totalCount;
    }

    public Integer getMonthCount() {
		return monthCount;
	}
	public void setMonthCount(Integer monthCount) {
		this.monthCount = monthCount;
	}
	public String getRtypeNo() {
		return rtypeNo;
	}
	public void setRtypeNo(String rtypeNo) {
		this.rtypeNo = rtypeNo;
	}
	public String getCallTime() {
		return callTime;
	}
	public void setCallTime(String callTime) {
		this.callTime = callTime;
	}
	public Integer getWorkType() {
		return workType;
	}
	public void setWorkType(Integer workType) {
		this.workType = workType;
	}
	public Boolean getIsServer() {
		return isServer;
	}
	public void setIsServer(Boolean isServer) {
		this.isServer = isServer;
	}
	public Long getRealConsumeMoney() {
		return realConsumeMoney;
	}
	public void setRealConsumeMoney(Long realConsumeMoney) {
		this.realConsumeMoney = realConsumeMoney;
	}
	public String getFromLastCheckTime() {
		return fromLastCheckTime;
	}
	public void setFromLastCheckTime(String fromLastCheckTime) {
		this.fromLastCheckTime = fromLastCheckTime;
	}
	public String getToLastCheckTime() {
		return toLastCheckTime;
	}
	public void setToLastCheckTime(String toLastCheckTime) {
		this.toLastCheckTime = toLastCheckTime;
	}
	public Integer getVipGrade() {
		return vipGrade;
	}
	public void setVipGrade(Integer vipGrade) {
		this.vipGrade = vipGrade;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public Boolean getIsSuccess() {
		return isSuccess;
	}
	public void setIsSuccess(Boolean isSuccess) {
		this.isSuccess = isSuccess;
	}
	public Double getEqualMoney() {
		return equalMoney;
	}
	public void setEqualMoney(Double equalMoney) {
		this.equalMoney = equalMoney;
	}
	public String getRebateType() {
		return rebateType;
	}
	public void setRebateType(String rebateType) {
		this.rebateType = rebateType;
	}
	public String getPropName() {
		return propName;
	}
	public void setPropName(String propName) {
		this.propName = propName;
	}
	public Double getPaymoney() {
		return paymoney;
	}
	public void setPaymoney(Double paymoney) {
		this.paymoney = paymoney;
	}
	public String getReceiver() {
		return receiver;
	}
	public void setReceiver(String receiver) {
		this.receiver = receiver;
	}
	public Double getConsumemoney() {
		return consumemoney;
	}
	public void setConsumemoney(Double consumemoney) {
		this.consumemoney = consumemoney;
	}
	public String getOrderid() {
		return orderid;
	}
	public void setOrderid(String orderid) {
		this.orderid = orderid;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getFromApplyTime() {
		return fromApplyTime;
	}
	public void setFromApplyTime(String fromApplyTime) {
		this.fromApplyTime = fromApplyTime;
	}
	public String getToApplyTime() {
		return toApplyTime;
	}
	public void setToApplyTime(String toApplyTime) {
		this.toApplyTime = toApplyTime;
	}
	public Double getRebatemoney() {
		return rebatemoney;
	}
	public void setRebatemoney(Double rebatemoney) {
		this.rebatemoney = rebatemoney;
	}
	public String getAporderid() {
		return aporderid;
	}
	public void setAporderid(String aporderid) {
		this.aporderid = aporderid;
	}
	public Integer getApplyType() {
		return applyType;
	}
	public void setApplyType(Integer applyType) {
		this.applyType = applyType;
	}
	public String getUsername() {
		return username;
	}
	public void setUsername(String username) {
		this.username = username;
	}
	public String getApplyTime() {
		return applyTime;
	}
	public void setApplyTime(String applyTime) {
		this.applyTime = applyTime;
	}
	public String getToaccount() {
		return toaccount;
	}
	public void setToaccount(String toaccount) {
		this.toaccount = toaccount;
	}
	public String getUid() {
		return uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public String getServerid() {
		return serverid;
	}
	public void setServerid(String serverid) {
		this.serverid = serverid;
	}
	public String getRoleid() {
		return roleid;
	}
	public void setRoleid(String roleid) {
		this.roleid = roleid;
	}
	public Double getMoney() {
		return money;
	}
	public void setMoney(Double money) {
		this.money = money;
	}
	public String getReason() {
		return reason;
	}
	public void setReason(String reason) {
		this.reason = reason;
	}
	public String getCrid() {
		return crid;
	}
	public void setCrid(String crid) {
		this.crid = crid;
	}
	public Integer getCheckstatus() {
		return checkstatus;
	}
	public void setCheckstatus(Integer checkstatus) {
		this.checkstatus = checkstatus;
	}
	public String getLastChecker() {
		return lastChecker;
	}
	public void setLastChecker(String lastChecker) {
		this.lastChecker = lastChecker;
	}
	public String getLastCheckTime() {
		return lastCheckTime;
	}
	public void setLastCheckTime(String lastCheckTime) {
		this.lastCheckTime = lastCheckTime;
	}
}

==> xlniuxdata-vipgame-1.0.211-sources.jar: com/xunlei/niux/data/vipgame/vo/RebateApply.java <==


package com.xunlei.niux.data.vipgame.vo;




import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


/**
 * 返利申请
 * @author 李苏
 * @date 2013-11-07
 * @Descripter:
 */
@Table(tableName="rebateapply",pkFieldName="seqid",pkFieldAssign=false)
public class RebateApply {

	private Long seqid;
	private String aporderid;
	private Integer applyType;
	private String rebateType;
	private String username;
	private String inputBy;
	private String applyTime;
	private String toaccount;
	private String uid;
	private Integer vipGrade;
	private String gameid;
	private String serverid;
	private String roleid;
	private Double money;
	private Double rebatemoney;
	private String reason;
	private String crid;
	private Integer checkstatus;
	private String lastChecker;
	private String lastCheckTime;
	@Column(columnName="lastCheckTime",isWhereColumn=true,operator=Operator.GE)
	private String fromLastCheckTime;
	@Column(columnName="lastCheckTime",isWhereColumn=true,operator=Operator.LT)
	private String toLastCheckTime;
	@Column(columnName="applyTime",isWhereColumn=true,operator=Operator.GE)
	private String fromApplyTime;
	@Column(columnName="applyTime",isWhereColumn=true,operator=Operator.LT)
	private String toApplyTime;
	
	private String orderid;
	private Double consumemoney;
	private Double paymoney;
    private String propName;
	private String receiver;
	private Double equalMoney;
	private Boolean isSuccess;
	private String editBy;



	private String editTime;
	private Long realConsumeMoney;
	private Boolean isServer;
	private Integer workType;
	private String callTime;
	private String rtypeNo;
    private Integer monthCount;
    private Integer totalCount;
	private Integer isReaded;
	@Column(columnName="money",isWhereColumn=true,operator=Operator.GE)
    private Double geMoney;

	public Integer getIsReaded() {
		return isReaded;
	}

	public Double getGeMoney() {
		return geMoney;
	}

	public void setGeMoney(Double geMoney) {
		this.geMoney = geMoney;
	}

	public void setIsReaded(Integer isReaded) {
		this.isReaded = isReaded;
	}
    public Integer getTotalCount() {
        return totalCount;
    }

    public void setTotalCount(Integer totalCount) {
        this.totalCount = totalCount;
    }

    public Integer getMonthCount() {
		return monthCount;
	}
	public void setMonthCount(Integer monthCount) {
		this.monthCount = monthCount;
	}
	public String getRtypeNo() {
		return rtypeNo;
	}
	public void setRtypeNo(String rtypeNo) {
		this.rtypeNo = rtypeNo;
	}
	public String getCallTime() {
		return callTime;
	}
	public void setCallTime(String callTime) {
		this.callTime = callTime;
	}
	public Integer getWorkType() {
		return workType;
	}
	public void setWorkType(Integer workType) {
		this.workType = workType;
	}
	public Boolean getIsServer() {
		return isServer;
	}
	public void setIsServer(Boolean isServer) {
		this.isServer = isServer;
	}
	public Long getRealConsumeMoney() {
		return realConsumeMoney;
	}
	public void setRealConsumeMoney(Long realConsumeMoney) {
		this.realConsumeMoney = realConsumeMoney;
	}
	public String getFromLastCheckTime() {
		return fromLastCheckTime;
	}
	public void setFromLastCheckTime(String fromLastCheckTime) {
		this.fromLastCheckTime = fromLastCheckTime;
	}
	public String getToLastCheckTime() {
		return toLastCheckTime;
	}
	public void setToLastCheckTime(String toLastCheckTime) {
		this.toLastCheckTime = toLastCheckTime;
	}
	public Integer getVipGrade() {
		return vipGrade;
	}
	public void setVipGrade(Integer vipGrade) {
		this.vipGrade = vipGrade;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	public Boolean getIsSuccess() {
		return isSuccess;
	}
	public void setIsSuccess(Boolean isSuccess) {
		this.isSuccess = isSuccess;
	}
	public Double getEqualMoney() {
		return equalMoney;
	}
	public void setEqualMoney(Double equalMoney) {
		this.equalMoney = equalMoney;
	}
	public String getRebateType() {
		return rebateType;
	}
	public void setRebateType(String rebateType) {
		this.rebateType = rebateType;
	}
	public String getPropName() {
		return propName;
	}
	public void setPropName(String propName) {
		this.propName = propName;
	}
	public Double getPaymoney() {
		return paymoney;
	}
	public void setPaymoney(Double paymoney) {
		this.paymoney = paymoney;
	}
	public String getReceiver() {
		return receiver;
	}
	public void setReceiver(String receiver) {
		this.receiver = receiver;
	}
	public Double getConsumemoney() {
		return consumemoney;
	}
	public void setConsumemoney(Double consumemoney) {
		this.consumemoney = consumemoney;
	}
	public String getOrderid() {
		return orderid;
	}
	public void setOrderid(String orderid) {
		this.orderid = orderid;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getInputBy() {
		return inputBy;
	}
	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}
	public String getFromApplyTime() {
		return fromApplyTime;
	}
	public void setFromApplyTime(String fromApplyTime) {
		this.fromApplyTime = fromApplyTime;
	}
	public String getToApplyTime() {
		return toApplyTime;
	}
	public void setToApplyTime(String toApplyTime) {
		this.toApplyTime = toApplyTime;
	}
	public Double getRebatemoney() {
		return rebatemoney;
	}
	public void setRebatemoney(Double rebatemoney) {
		this.rebatemoney = rebatemoney;
	}
	public String getAporderid() {
		return aporderid;
	}
	public void setAporderid(String aporderid) {
		this.aporderid = aporderid;
	}
	public Integer getApplyType() {
		return applyType;
	}
	public void setApplyType(Integer applyType) {
		this.applyType = applyType;
	}
	public String getUsername() {
		return username;
	}
	public void setUsername(String username) {
		this.username = username;
	}
	public String getApplyTime() {
		return applyTime;
	}
	public void setApplyTime(String applyTime) {
		this.applyTime = applyTime;
	}
	public String getToaccount() {
		return toaccount;
	}
	public void setToaccount(String toaccount) {
		this.toaccount = toaccount;
	}
	public String getUid() {
		return uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public String getServerid() {
		return serverid;
	}
	public void setServerid(String serverid) {
		this.serverid = serverid;
	}
	public String getRoleid() {
		return roleid;
	}
	public void setRoleid(String roleid) {
		this.roleid = roleid;
	}
	public Double getMoney() {
		return money;
	}
	public void setMoney(Double money) {
		this.money = money;
	}
	public String getReason() {
		return reason;
	}
	public void setReason(String reason) {
		this.reason = reason;
	}
	public String getCrid() {
		return crid;
	}
	public void setCrid(String crid) {
		this.crid = crid;
	}
	public Integer getCheckstatus() {
		return checkstatus;
	}
	public void setCheckstatus(Integer checkstatus) {
		this.checkstatus = checkstatus;
	}
	public String getLastChecker() {
		return lastChecker;
	}
	public void setLastChecker(String lastChecker) {
		this.lastChecker = lastChecker;
	}
	public String getLastCheckTime() {
		return lastCheckTime;
	}
	public void setLastCheckTime(String lastCheckTime) {
		this.lastCheckTime = lastCheckTime;
	}
}
